

import 'package:date_format/date_format.dart';
import 'package:flutter/material.dart';
import 'package:nan_common_utils/nan_base_dialog.dart';
import 'package:nan_common_utils/nan_widget_util.dart';
import 'package:uuid/uuid.dart';
import 'dart:ui';

class NanUtil{
  static getImagePath(String name,{String path="img",String format:'png'}){
    return '$path/$name.$format';
  }

  static isEmpty(content){//返回对应的内容
    if(content == null || content == '' || content.length == 0){
      return '';
    }
    return content;
  }

  static isStrEmpty(content){//判断是否为空
    if(content == null || content == "" || content.length == 0 || content.trim().length==0){
      return true;
    }
    return false;
  }

  static isStrNotEmpty(content){//判断不为空
    return !isStrEmpty(content);
  }

  static int currentTimeMillis() {//当前时间戳
    return new DateTime.now().millisecondsSinceEpoch;
  }

  static isListEmpty(List content){
    if(content == null || content.length == 0){
      return true;
    }
    return false;
  }

  static isListNotEmpty(List content){
    return !isListEmpty(content);
  }

  static bool contains(String text,{String content}){//某个字符串是否包含另一个字符串
    if (text.contains(content)) {
      return true;
    }
    return false;
  }

  static isMapEmpty(Map content){
    if(content == null || content.length == 0){
      return true;
    }
    return false;
  }

  static isMapNotEmpty(Map content){
    
    return !isMapEmpty(content);
  }

  static String comShowText({Object content,String placeholder}){
    if(content == null){
      return placeholder ==null ? '':placeholder;
    }
    return "$content";
  }

  //是否同时包含数字和字母
 static String isLetterNum(String conetent){
    List<String> l2 = ["0", "1", "2","3","4","5","6","7","8","9"];
    bool isNum = false;
    String status = NanLetterNumType.Letter;//证明是纯字母
    for (var value in l2) {
      if(conetent.contains(value)){
        isNum = true;
        break;
      }
    }
    if(isNum){
      try{
        double.parse(conetent);
        status = NanLetterNumType.Num;//转成功了，证明是纯数字
      }catch(e){
        status = NanLetterNumType.LetterNum;//转失败了，证明是数字和字母组合
      }
    }
    return status;    
  }

  //校验手机号
  static bool regExpPhone(String phone){
    RegExp exp = RegExp(
          r'^((13[0-9])|(14[0-9])|(15[0-9])|(16[0-9])|(17[0-9])|(18[0-9])|(19[0-9]))\d{8}$');
    bool matched = exp.hasMatch(phone);
    if (!matched) {
      return false;
    }
    if (phone.length != 11) {
      return false;
    }
    return true;
  }

  static String uuid({keyuserpassword:'com.company.app.usernamepassword'}){
    var uuid = new Uuid();
    String uuids = uuid.v5(Uuid.NAMESPACE_URL, keyuserpassword);
    return uuids;
  }

  static String dateFormtter(val){
    return formatDate(val, [yyyy, "-", mm, "-", dd]);
  }

  static bool boolDefaultValue({Object value,bool defaultValue=false}){
    if (value is String) {
      if (isStrEmpty(value)) {
        return defaultValue;
      }else{
        return true;
      }
    }
    if (value is bool) {
      return value;
    }
    return defaultValue;
  }

  //通过符号拼接，比如： (通过“，”拼接)
  static String joinBySybol(List list,{String symbol=","}){
    String str = '';
    list.forEach((f){
      if(str == ''){
        str = "$f";
      }else {
        str = "$str""$symbol""$f";
      }
    });

    return str;
  }

  //判断是否是相片
  static bool isImg(String url){
    String imgUrl = url.toLowerCase();
    if (imgUrl.contains('.jpg') || 
        imgUrl.contains('.png') ||
        imgUrl.contains('.jpeg') ||  
        imgUrl.contains('.svg') ||  
        imgUrl.contains('.gif')) {
          return true;
    }
    return false;
  }

  //判断是否是视频
  static bool isVideo(String url){
    String imgUrl = url.toLowerCase();
    if (imgUrl.contains('.MP4') || 
        imgUrl.contains('.mp4') ||
        imgUrl.contains('.MOV') ||  
        imgUrl.contains('.mov') ||  
        imgUrl.contains('.rmvb') ||  
        imgUrl.contains('.rm')||

        imgUrl.contains('.avi') ||  
        imgUrl.contains('.FLV') ||  
        imgUrl.contains('.3GP')  ) {
          return true;
    }
    return false;
  }

  static void showUploadDialog(BuildContext context,{String upload,Color loadingColor,bool isDismiss=false,double radius=8,String tipMsg="提示文字",GestureTapCallback onTap}){
    showDialog(context: context,barrierDismissible: isDismiss,builder: (context) {
      return NanBaseDialog(
        Column(
          children: <Widget>[
            SizedBox(height: 20,),
            NanWidgetUtil.loadingWidget(loadingColor: loadingColor),
            InkWell(
              child: Padding(
                padding: EdgeInsets.only(top: 20),
                child: Text(tipMsg),
              ),
              onTap: onTap,
            )
          ],
        ), 
        150, 
        NanUtil.kScreenWidth - 46*2, 
        radius
      );
    },);
  }

  //屏幕
  static double kHeightStatusBar = MediaQueryData.fromWindow(window).padding.top;//留海顶部
  static double kHBottom = MediaQueryData.fromWindow(window).padding.bottom;//底部
  static double kScreenHeight = MediaQueryData.fromWindow(window).size.height;//屏幕高
  static double kScreenWidth = MediaQueryData.fromWindow(window).size.width;//屏幕宽
}

class NanLetterNumType{
  static const String Num = 'NUM';//数字
  static const String Letter = 'LETTER';//字母
  static const String LetterNum = 'LetterNum';//数字和字母组合
}

class NanCheckPhotoType {
  static const int NetType = 1;
  static const int LocalType = 2;
}

class NanLineType{
  static const String custom="custom";
  static const String divider = "Divider";
}

class NanActionType {
  static const int TextType = 1;
  static const int ImgType = 2;
}

class MapType {
  static const int MAMapTypeStandard = 1;//标准地图
  static const int MAMapTypeSatellite = 2;//卫星地图
  static const int MAMapTypeStandardNight = 2;//夜景模式地图
  static const int MAMapTypeStandardNavi = 2;//导航模式地图

}